@@ -21,7 +21,7 @@
 #'
 #' Type: R package
 #'
-#' Version: 1.1.0 (June 2019: dplyr update)
+#' Version: 1.1.1 (November 2020, compatibility with R 4.0)
 #'
 #' License: GPL-3
 #' @note
@@ -50,7 +50,7 @@
 #' # setwd()
 #'
 #' # If you want to have an organisational chart of the functions:
-#' \donttest{
+#' \dontrun{
 #' pdfDisplay(StratigrapheR(), "Organisational Chart StratigrapheR",
 #'            width = 9, height = 7.5, track = FALSE)}
 #'
@@ -511,7 +511,7 @@
 #' # causes the pdf to open, only works in Windows. If You are working with
 #' # Windows, I recommend using SumatraPDF as your default pdf reader: this will
 #' # allow pdfs to be changed while they are being visualised.
-#' \donttest{
+#' \dontrun{
 #' pdfDisplay(repeated.log(), width = 10, height = 15,
 #'           name = "StratigrapheR_Example_a", track = FALSE)}
 #'
@@ -553,7 +553,7 @@
 #'   par(mar = opar$mar, mfrow = opar$mfrow)
 #'
 #' }
-#' \donttest{
+#' \dontrun{
 #' pdfDisplay(graphical.function.1(), width = 10, height = 15,
 #'            name = "StratigrapheR_Example_b", track = FALSE)}
 #'
@@ -561,7 +561,7 @@
 #' # use LaTeX. The following lines of code will create a TeX file that would
 #' # do that, test it if you want (the file will be in a temporary directory,
 #' # but you can change tempdir(), to getwd() for instance):
-#' \donttest{
+#' \dontrun{
 #' writeLines(log.loop.tex, paste(tempdir(),"log.loop.tex", sep = "/"))}
 #'
 #' # Another way to work this out is to create more space than needed on the
@@ -601,7 +601,7 @@
 #'   par(mar = omar)
 #'
 #' }
-#' \donttest{
+#' \dontrun{
 #' pdfDisplay(graphical.function.2(), width = 8, height = 15,
 #'            name = "StratigrapheR_Example_c", track = FALSE)}
 #'
@@ -770,7 +770,8 @@ StratigrapheR <- function(i = 1:3)
 
 utils::globalVariables(c("gloVar.neworder", "gloVar.ni", "gloVar.bs",
                          "gloVar.k", "gloVar.adapt.buttons",
-                         "gloVar.x", "gloVar.i", "gloVar.xy", "gloVar.o"))
+                         "gloVar.x", "gloVar.i", "gloVar.xy", "gloVar.o",
+                         "glovar.wdt", "glovar.order"))
 
 
 
